@@ -26,7 +26,7 @@ from fdasrsf.rbfgs import rlbfgs
 import sys
 
 
-def smooth_data(f, sparam):
+def smooth_data(f, sparam=1):
     """
     This function smooths a collection of functions using a box filter
 
@@ -41,10 +41,10 @@ def smooth_data(f, sparam):
     N = f.shape[1]
 
     fo = f.copy()
-    for k in range(1, sparam):
+    for k in range(0, sparam):
         for r in range(0, N):
-            fo[1:(M - 2), r] = (f[0:(M - 3), r] + 2 * f[1:(M - 2), r] +
-                               f[2:(M - 1), r]) / 4
+            fo[1:(M - 2), r] = (fo[0:(M - 3), r] + 2 * fo[1:(M - 2), r] +
+                               fo[2:(M - 1), r]) / 4
     return fo
 
 
@@ -294,8 +294,8 @@ def elastic_distance(f1, f2, time, method="DP2", lam=0.0):
     q2 = f_to_srsf(f2, time)
 
     gam = optimum_reparam(q1, time, q2, method, lam)
-    fw = interp((time[-1] - time[0]) * gam + time[0], time, f2)
-    qw = f_to_srsf(fw, time)
+    fw = warp_f_gamma(time, f2, gam)
+    qw = warp_q_gamma(time, q2, gam)
 
     Dy = sqrt(trapz((qw - q1) ** 2, time))
     M = time.shape[0]
